<?php
/**
 * This file contains various tests for opening_hours.
 * Tests are combined in an array. Each test is a array with the two
 * elements 'oh', 'er'. 'oh' is a string holding the specification for
 * the opening hours. 'er' is the expected result. 1 means the given
 * date/time is within the opening hours, 0 means it is outside the
 * opening hours. If evaluateInTime() does not return the expected
 * result, the test has failed.
 */

include "../OSM_OpeningHours.php";

function runTests($tests, $osmhours, $date) {
	echo "Running ".count($tests)." tests for ".date('r', $date->getUnixTimestamp())."\n";
	foreach($tests as $test) {
		echo "Run test for '".$test['oh']."'. Expect ".($test['er']?'open':'closed')."\n";
		$result = $osmhours->evaluateInTime($test['oh'], $date);
		if($result->hasErrors()) {
			echo "  Test failed because of syntax errors:\n";
			foreach($result->getErrors() as $error)
				echo "  Error: ".$error."\n";
		} else {
			if($result->hasWarnings()) {
				foreach($result->getWarnings() as $warning)
					echo "  Warning: ".$warning."\n";
			}
			if($comment = $result->getComment()) {
				echo "  Comment: ".$comment."\n";
			}
			if($result->isOpen() == $test['er']) {
				echo "  Test succeded\n";
			} else {
				echo "  Test failed\n";
			}
		}
	}
}

// Fr, 27 Jan. 2012 11:02:02
$date = new OSM_OpeningHours_Date(2012, 1, 27, 11, 2, 2);
$osmhours = new OSM_OpeningHours();

/* */
$tests = array(
	array('oh'=>'Ph', 'er' => 0),
	array('oh'=>'closed', 'er' => 0),
	array('oh'=>'Mo-Sa 10:00-12:00;Fr off', 'er' => 0),
	array('oh'=>'Mo-Sa 10:00-12:00 open "Durchgehend warme Küche"', 'er' => 1),
	array('oh'=>'Fr', 'er' => 1),
	array('oh'=>'Fr-Sa', 'er' => 1),
	array('oh'=>'Mo,Fr', 'er' => 1),
	array('oh'=>'Mo,Su', 'er' => 0),
	array('oh'=>'Mo-Fr,Su', 'er' => 1),
	array('oh'=>'Sa', 'er' => 0),
	array('oh'=>'Fr[4]', 'er' => 1),
	array('oh'=>'Th[4]', 'er' => 0),
	array('oh'=>'10:00-12:00', 'er' => 1),
	array('oh'=>'12:00-13:00', 'er' => 0),
	array('oh'=>'10:00+', 'er' => 1),
	array('oh'=>'11:30+', 'er' => 0),
	array('oh'=>'Mo-Su 10:30+', 'er' => 1),
	array('oh'=>'Fr 10:00-14:00', 'er' => 1),
	array('oh'=>'Fr 10:00-11:00', 'er' => 0),
	array('oh'=>'Fr-Sa 10:00-14:00', 'er' => 1),
	array('oh'=>'Mo-Th 10:00-14:00', 'er' => 0),
	array('oh'=>'Jan 27: 10:00-14:00', 'er' => 1),
	array('oh'=>'Jan 27.', 'er' => 1),
	array('oh'=>'Jan 27', 'er' => 1),
	array('oh'=>'Jan 21-28:', 'er' => 1),
	array('oh'=>'Jan: off', 'er' => 0),
	array('oh'=>'Jan:', 'er' => 1),
	array('oh'=>'Feb', 'er' => 0),
	array('oh'=>'week 4 fr', 'er' => 1),
	array('oh'=>'week 2 fr', 'er' => 0),
	array('oh'=>'week 4 th', 'er' => 0),
	array('oh'=>'week 2-5 fr', 'er' => 1),
	array('oh'=>'Th-Su,Mo 17:00-24:00;Su 11:30-24:00;We 15:00-17:00', 'er' => 0),
	array('oh'=>'Mo-Su 09:00-14:00 open;Mo-Su 11:10-13:00 open "Warme Küche"', 'er' => 1),
);

runTests($tests, $osmhours, $date);

/* Check for 1. Jan 2012 */
$date = new OSM_OpeningHours_Date(2012, 1, 1, 11, 2, 2);
$tests = array(
	array('oh'=>'Ph', 'er' => 1),
);
runTests($tests, $osmhours, $date);

/* Check for 6. Apr 2012 (Karfreitag) */
$date = new OSM_OpeningHours_Date(2012, 4, 6, 11, 2, 2);
$osmhours->addHoliday('de', 'public', 'Fronleichnahm', 2012, 6, 7);
$osmhours->addHoliday('de', 'school', 'Sommer1', 2012, 4, 5);
$tests = array(
	array('oh'=>'Ph-1 days', 'er' => 0),
	array('oh'=>'Ph days', 'er' => 0),
	array('oh'=>'Sh 10:00-15:00 open "alfk"', 'er' => 1),
	array('oh'=>'Sh+1 days', 'er' => 1),
	array('oh'=>'Fr-We 10:00-18:00; Fr off', 'er' => 0),
	array('oh'=>'Fr-We 10:00-18:00; Fr off; Ph 10:00-18:00', 'er' => 1),
);
runTests($tests, $osmhours, $date);

?>
